@@ -1,20 +1,24 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from __future__ import annotations
+
+import logging
+
+from typing import Any
 
 from .abstractgenerator import AbstractMISPObjectGenerator
-import logging
 
 logger = logging.getLogger('pymisp')
 
 
 class GitVulnFinderObject(AbstractMISPObjectGenerator):
 
-    def __init__(self, parameters: dict, strict: bool=True, standalone: bool=True, **kwargs):
-        super(GitVulnFinderObject, self).__init__('git-vuln-finder', strict=strict, standalone=standalone, **kwargs)
+    def __init__(self, parameters: dict[str, Any], strict: bool = True, **kwargs) -> None:  # type: ignore[no-untyped-def]
+        super().__init__('git-vuln-finder', strict=strict, **kwargs)
         self._parameters = parameters
         self.generate_attributes()
 
-    def generate_attributes(self):
+    def generate_attributes(self) -> None:
         authored_date = self._sanitize_timestamp(self._parameters.pop('authored_date', None))
         self._parameters['authored_date'] = authored_date
         committed_date = self._sanitize_timestamp(self._parameters.pop('committed_date', None))
@@ -25,4 +29,4 @@ class GitVulnFinderObject(AbstractMISPObjectGenerator):
             self._parameters['stats.deletions'] = stats.pop('deletions')
             self._parameters['stats.lines'] = stats.pop('lines')
             self._parameters['stats.files'] = stats.pop('files')
-        return super(GitVulnFinderObject, self).generate_attributes()
+        super().generate_attributes()
